#!/bin/bash

# get the cloudinit ubuntu 22.04 img
eval "wget https://cloud-images.ubuntu.com/minimal/releases/jammy/release/ubuntu-22.04-minimal-cloudimg-amd64.img"

mv ubuntu-22.04-minimal-cloudimg-amd64.img ubuntu.img

# Install libguestfs-tools on Proxmox server.
apt-get install libguestfs-tools -y
# Install qemu-guest-agent on Ubuntu image.
virt-customize -a ubuntu.img --install qemu-guest-agent
# to let vm will not get same ip address if using dhcp
virt-customize -a ubuntu.img --run-command "echo -n > /etc/machine-id"



export STORAGE_POOL=local-lvm
export VM_ID=$1
export VM_NAME=ubuntu-22.04-cloudinit

# Create Proxmox VM image from Ubuntu Cloud Image.
qm create $VM_ID --name $VM_NAME --memory 2048 --cores 2 --net0 virtio,bridge=vmbr0
qm importdisk $VM_ID ubuntu.img $STORAGE_POOL
qm set $VM_ID --scsihw virtio-scsi-pci --scsi0 $STORAGE_POOL:vm-$VM_ID-disk-0
# Create Cloud-Init Disk and configure boot.
qm set $VM_ID --ide2 $STORAGE_POOL:cloudinit
qm set $VM_ID --boot c --bootdisk scsi0
qm set $VM_ID --serial0 socket --vga serial0
qm set $VM_ID --agent enabled=1
qm template $VM_ID
